# Define pkgdocdir for releases that don't define it already
%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}
%{!?ruby_vendorlibdir: %global ruby_vendorlibdir %(ruby -rrbconfig -e 'puts RbConfig::CONFIG["sitelibdir"]')}
%{!?ruby_vendorarchdir: %global ruby_vendorarchdir %(ruby -rrbconfig -e 'puts RbConfig::CONFIG["sitearchdir"]')}

# We ship a .pc file but don't need to depend on pkg-config
%global __requires_exclude pkg-config
%global __provides_exclude_from ^(%{python_sitearch}/.*\\.so|%{_libdir}/.libqmf*)$

Name:    qpid-qmf
Version: 0.32
Release: 3%{?dist}
Summary: The QPID Management Framework
License: ASL 2.0
URL:     http://qpid.apache.org

Source0:   qpid-%{version}.tar.gz
Patch3:    qpid-boost-test-message.patch

BuildRequires: cmake
BuildRequires: swig
BuildRequires: python2-devel
BuildRequires: ruby-devel
BuildRequires: boost-devel
BuildRequires: libuuid-devel

Requires:  qpid(cpp-client)%{?_isa}
Requires:  python-qpid
Requires:  python-qpid-qmf%{?_isa} = %{version}-%{release}


%description
The Qpid Management Framework is a general-purpose management bus built on Qpid
messaging. It takes advantage of the scalability, security, and rich
capabilities of Qpid to provide flexible and easy-to-use manageability to a
large set of applications.



%package devel
Summary:   Header files and tools for developing QMF extensions

Requires:  qpid-qmf%{?_isa} = %{version}-%{release}
Requires:  qpid(cpp-client-devel)%{?_isa}

%description devel
Header files and code-generation tools needed for developers of QMF-managed
components.

%files devel
%{_includedir}/qmf
%{_libdir}/libqmf2.so
%{_bindir}/qmf-gen
%{python_sitelib}/qmfgen
%{_libdir}/pkgconfig/qmf2.pc

%post devel -p /sbin/ldconfig

%postun devel -p /sbin/ldconfig



%package -n python-qpid-qmf
Summary:   The QPID Management Framework bindings for python

Requires:  qpid-qmf%{?_isa} = %{version}-%{release}


%description -n python-qpid-qmf
An extensible management framework layered on QPID messaging, bindings
for python.

%files -n python-qpid-qmf
%exclude %{python_sitelib}/qpidtoollibs
%{python_sitearch}/qmf
%{python_sitearch}/qmf2.py*
%{python_sitearch}/cqmf2.py*
%{python_sitearch}/_cqmf2.so

%post -n python-qpid-qmf -p /sbin/ldconfig

%postun -n python-qpid-qmf -p /sbin/ldconfig



%package -n ruby-qpid-qmf
Summary:   The QPID Management Framework bindings for ruby

Requires:  qpid-qmf%{?_isa} = %{version}-%{release}


%description -n ruby-qpid-qmf
An extensible management framework layered on QPID messaging, bindings
for ruby.

%files -n ruby-qpid-qmf
%{ruby_vendorlibdir}/qmf2.rb
%{ruby_vendorarchdir}/cqpid.so
%{ruby_vendorarchdir}/cqmf2.so

%post -n ruby-qpid-qmf -p /sbin/ldconfig

%postun -n ruby-qpid-qmf -p /sbin/ldconfig


%files -n qpid-qmf
#%{_bindir}/qmf-tool
%{_libdir}/libqmf2.so.*
%doc %{_pkgdocdir}

%post -n qpid-qmf -p /sbin/ldconfig

%postun -n qpid-qmf -p /sbin/ldconfig



%prep
%setup -q -n qpid-%{version}

%patch3 -p1

%build
pushd cpp
%cmake -DDOC_INSTALL_DIR:PATH=%{_pkgdocdir} .
make %{?_smp_mflags}

pushd ../python
./setup.py build
popd
pushd ../extras/qmf
./setup.py build
popd

%install
rm -rf %{buildroot}

pushd cpp
make install DESTDIR=%{buildroot}
popd

pushd python
%{__python} setup.py install \
   --skip-build \
   --install-purelib %{python_sitearch} \
   --root %{buildroot}
popd

pushd extras/qmf
%{__python} setup.py install \
    --skip-build \
    --install-purelib %{python_sitearch} \
    --root %{buildroot}
popd

# clean up items we're not installing
rm -f %{buildroot}/%{_libdir}/libqpidbroker.so
rm -f %{buildroot}/%{_libdir}/libcqpid_perl.so
rm -f %{buildroot}/%{_libdir}/ruby/cqmf2.so
rm -f %{buildroot}/%{_libdir}/ruby/cqpid.so
rm -f %{buildroot}/%{_libdir}/ruby/qmfengine.so
rm -f %{buildroot}/%{ruby_sitelib}
rm -rf %{buildroot}/%{_libdir}/perl5

# delete items not used by the QMF packages
rm -rf %{buildroot}/etc/qpid
rm -rf %{buildroot}/%{_initrddir}
rm -rf %{buildroot}/%{_sysconfdir}/sasl2
rm -rf %{buildroot}/%{_bindir}/qpid*
rm -rf %{buildroot}/%{_sbindir}/qpidd
rm -rf %{buildroot}/%{_includedir}/qpid
rm -rf %{buildroot}/%{python_sitelib}/qpid
rm -rf %{buildroot}/%{python_sitelib}/qpid_tools*
rm -rf %{buildroot}/%{python_sitearch}/mllib
rm -rf %{buildroot}/%{python_sitearch}/qpid
rm -rf %{buildroot}/%{python_sitelib}/*egg-info
rm -rf %{buildroot}/%{python_sitearch}/*egg-info
rm -rf %{buildroot}/%{python_sitearch}/*qpid_messaging.*
rm -rf %{buildroot}/%{_libdir}/libqpid*
rm -rf %{buildroot}/%{_libdir}/librdmawrap*
rm -rf %{buildroot}/%{_libdir}/qpid
rm -rf %{buildroot}/%{_libdir}/pkgconfig/qpid.pc
rm -rf %{buildroot}/%{_pkgdocdir}/api
rm -rf %{buildroot}/%{_mandir}
rm -rf %{buildroot}/%{_datadir}/qpid/examples
rm -rf %{buildroot}/%{_libexecdir}/qpid
rm -rf %{buildroot}/%{_libdir}/cmake

# Set executable bit on shared libraries to ensure the binaries are stripped
chmod +x %{buildroot}/%{python_sitearch}/*so

# QMF Python management
install -d %{_builddir}/cpp/managementgen/qmfgen \
           %{buildroot}/%{python_sitelib}

# QMF Ruby package
install -d %{buildroot}%{ruby_vendorlibdir}
install -d %{buildroot}%{ruby_vendorarchdir}

#install -pm 644 %{_builddir}/qpid-%{version}/cpp/bindings/qmf/ruby/qmf.rb \
#     %{buildroot}%{ruby_vendorlibdir}
install -pm 644 %{_builddir}/qpid-%{version}/cpp/bindings/qmf2/ruby/qmf2.rb \
    %{buildroot}%{ruby_vendorlibdir}

%if 0%{?fedora} > 20
install -pm 755 %{_builddir}/qpid-%{version}/cpp/bindings/qpid/ruby/cqpid_ruby.so \
     %{buildroot}%{ruby_vendorarchdir}/cqpid.so
#install -pm 755 %{_builddir}/qpid-%{version}/cpp/bindings/qmf/ruby/qmfengine_ruby.so \
#    %{buildroot}%{ruby_vendorarchdir}/qmfengine.so
install -pm 755 %{_builddir}/qpid-%{version}/cpp/bindings/qmf2/ruby/cqmf2_ruby.so \
    %{buildroot}%{ruby_vendorarchdir}/cqmf2.so
%else
install -pm 755 %{_builddir}/qpid-%{version}/cpp/bindings/qpid/ruby/libcqpid_ruby.so \
     %{buildroot}%{ruby_vendorarchdir}/cqpid.so
#install -pm 755 %{_builddir}/qpid-%{version}/cpp/bindings/qmf/ruby/libqmfengine_ruby.so \
#    %{buildroot}%{ruby_vendorarchdir}/qmfengine.so
install -pm 755 %{_builddir}/qpid-%{version}/cpp/bindings/qmf2/ruby/libcqmf2_ruby.so \
    %{buildroot}%{ruby_vendorarchdir}/cqmf2.so
%endif

# clean up leftover ruby files
rm -rf %{buildroot}/usr/local/%{_lib}/ruby/site_ruby



%changelog
* Fri Jan 15 2016 Jonathan Wakely <jwakely@redhat.com> - 0.32-3
- Rebuilt for Boost 1.60

* Tue Jan 12 2016 Vít Ondruch <vondruch@redhat.com> - 0.32-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/Ruby_2.3

* Wed Sep  2 2015 Irina Boverman <iboverma@redhat.com> - 0.32-1
- Rebased to 0.32 
- Dropped qpid-tools as "Required" for python-qpid-qmf

* Sun Aug 30 2015 Jonathan Wakely <jwakely@redhat.com> 0.28-33
- Patched and rebuilt for Boost 1.59

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 0.28-31
- rebuild for Boost 1.58

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.28-30
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Jun  1 2015 Darryl L. Pierce <dpierce@redhat.com> - 0.28-29
- Add transitional dependency to python-qpid-qmf on qpid-tools.

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.28-28
- Rebuilt for GCC 5 C++11 ABI change

* Wed Feb 25 2015 Darryl L. Pierce <dpierce@redhat.com> - 0.28-28
- Removed qpidtoollibs from python-qpid-qmf.
- * This will be provides by the qpid-tools package in future.

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> - 0.28-27
- Rebuild for boost 1.57.0

* Sun Jan 18 2015 Mamoru TASAKA <mtasaka@fedoraproject.org> - 0.28-26
- Rebuild for https://fedoraproject.org/wiki/Changes/Ruby_2.2

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.28-25
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Aug 14 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.28-24
- Updated the requires on Qpid virtual packages.

* Wed Jul  9 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.28-23
- Removed intra-package comments that were pulled into the postun scripts.

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.28-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Jun  5 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.28-1
- Rebased on Qpid 0.28.

* Mon Jun  2 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.24-21
- Missed the arch reference on one requires.

* Mon Jun  2 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.24-20
- Added arch reference to qpid client requirement.
- Resolves: BZ#1103373

* Fri May 23 2014 David Tardon <dtardon@redhat.com> - 0.24-19
- rebuild for boost 1.55.0

* Thu May 22 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.24-18
- Changed dependencies on qpid-cpp-client to be qpid(client).

* Mon May  5 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.24-17
- Fixed FTBFS on F21 due to dead code.

* Mon Feb  3 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.24-16
- Fix dependencies onto qpid-cpp packages to be >= 0.24.
- Fixed building with -Werror=format-security enabled.

* Thu Oct 31 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.24-15
- First separate build of QMF packages for Fedora.
- Changed shebangs to use explicit references to interpreters.

* Wed Oct 30 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.24-14
- Added dependency from qpid-qmf onto python-qpid-qmf.

* Tue Oct 29 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.24-13
- Removed release portion of Requires.
- QPID-5273: Fixed installation of qmfgen Python library.

* Mon Oct 28 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.24-12
- Added missing dist tag.
- Added filters for Swig-generated binding libraries.
- Set executable bit on Python libraries to ensure they're stripped.

* Fri Oct 25 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.24-11
- Removed unused global macros.
- Removed BR for python since it's provided by python-devel.
- Changed BR for python-devel to python2-devel.
- Removed BR for ruby since it's provided by ruby-devel.
- Added project description from the QMF website to qpid-qmf package.
- Made qpid-qmf owner of pkgdocdir.
- Filter out pkgconfig dependency.

* Thu Oct 17 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.24-10
- Initial attempt at separately packaging the QMF code.
